#![allow(dead_code, unused_imports)]
use actix_web::web::{Data, Query};
use actix_web::{web::scope, App, HttpServer};
use log::info;
// use uuid::Uuid;

mod routes;
mod state;
mod types;

use routes::{get_posts, new_post, register, test};
use sqlx::ConnectOptions;
use state::AppState;

use sqlx::{migrate::MigrateDatabase, query, sqlite};

struct User {
    name: String,
    pass: String,
}

#[actix_web::main]
async fn main() -> std::io::Result<()> {
    env_logger::Builder::from_env(env_logger::Env::default().default_filter_or("debug")).init();

    let data = AppState::new().await;

    info!("Spinning up server on http://localhost:8080");
    HttpServer::new(move || {
        App::new().service(
            scope("api")
                .service(get_posts)
                .service(new_post)
                .service(routes::vote)
                .service(test)
                .service(register)
                .app_data(Data::new(data.clone())),
        )
    })
    .bind("localhost:8080")?
    .run()
    .await
}
